@@ -124,10 +124,6 @@ class App:
         await response(scope, recieve, send)
 
     async def __call__(self, scope, recieve, send):
-        if "static" in scope["path"]:
-            # await self.static_app(scope, recieve, send)
-            await self.static_test(scope["path"])
-
         await self.middleware(scope, recieve, send)
 
     def handle_request(self, request):
