@@ -12,9 +12,9 @@ class StaticFile:
     def __init__(self, directory):
         self.directory = directory
     
-    async def __call__(self, request, path: str):
+    def __call__(self, request, filename: str):
         headers = {}
-        filename = os.path.basename(path)
+        path = os.path.relpath(filename, os.getcwd())
         
         with open(path, "rb") as f:
             data = f.read()
@@ -27,4 +27,6 @@ class StaticFile:
             }
         )
         
-        return Response(data, media_type=mimetype)
\ No newline at end of file
+        return Response(data, media_type=mimetype)
+
+
